@@ -11,7 +11,7 @@ def config2json(path):
     :return 返回json eg: {"项名":{"选项":"值"}
     """
     _dict = {}
-    conf = configparser.ConfigParser()
+    conf = configparser.RawConfigParser()
     conf.read(path, encoding="utf-8")
     sections = conf.sections()
     for item in sections:
@@ -26,7 +26,7 @@ def json2config(path, _dict):
     :param path: 配置文件路径,eg: config.ini/config.conf/config.cfg
     :param _dict: json格式 eg: {"项名":{"选项":"值"}
     """
-    conf = configparser.ConfigParser()
+    conf = configparser.RawConfigParser()
     for section in _dict:
         conf.add_section(section)
         for k, v in _dict[section]:
