@@ -34,7 +34,7 @@ def fofa(email, key, query_list, fields, size=100, max_page=100, check_url=True)
     :param query_list eg: ['app="tomcat"']
     :param fields eg: ['host','title','ip','domain','port','protocol','city']
     '''
-    results = []
+    result = []
     for query_str in query_list:
         for page in range(1, max_page+1):
             try:
@@ -52,7 +52,7 @@ def fofa(email, key, query_list, fields, size=100, max_page=100, check_url=True)
                     if check_url:
                         _.update({'url': _['host'] if 'http' in _[
                                  'host'] else "http://"+_['host']})
-                    results.append(_)
+                    result.append(_)
             else:
                 break
-    return results
+    return result
