@@ -4,28 +4,42 @@
 import re
 import ipaddress
 
-from .common_help import gen_ip, ip2num, num2ip, num2numnum
+from .common_help import num2numnum
 
+def ip2num(ip):
+    return int(ipaddress.ip_address(ip))
+
+def num2ip(num):
+    return ipaddress.ip_address(num).compressed
+
+def gen_ip(start_ip,end_ip):
+    """
+    根据IP范围生成IP
+    :param start_ip: 1.1.1.1
+    :param end_ip: 1.1.1.3
+    :return ['1.1.1.1','1.1.1.2']
+    """
+    return [num2ip(num) for num in range(ip2num(start_ip), ip2num(end_ip)+1)]
 
 def net2ipip(net_str, strict=False):
     """
     转化单个其他网段格式成单个ip-ip格式
     :param net_str: 传入合法网段,eg: 192.168.1.0/24 or 192.168.1.1-33 or 192.168.1.5-192.168.1.8
-    :return 返回 192.168.1.5-192.168.1.8
+    :return 返回 ['192.168.1.5','192.168.1.8']
     """
 
     if re.search(r"^\d+\.\d+\.\d+\.\d+-\d+$", net_str):
         _net, a, b = re.findall(r"(\d+\.\d+\.\d+\.)(\d+)-(\d+)", net_str)[0]
-        net = "{}{}-{}{}".format(_net,a,_net,b)
+        ipip = [f'{_net}{a}',f'{_net}{b}']
     elif re.match(r"^\d+\.\d+\.\d+\.\d+-\d+\.\d+\.\d+\.\d+$", net_str):
-        net = net_str
+        ipip = re.findall(r"(\d+\.\d+\.\d+\.\d+)-(\d+\.\d+\.\d+\.\d+)", net_str)[0]
     else:
         try:
-            net = '{}-{}'.format(ipaddress.ip_network(net_str, strict=strict).network_address.compressed,ipaddress.ip_network(net_str, strict=strict).broadcast_address.compressed)
+            ipip = [ipaddress.ip_network(net_str, strict=strict).network_address.compressed,ipaddress.ip_network(net_str, strict=strict).broadcast_address.compressed]
         except Exception as e:
             print('{} ,error:{}'.format(net_str,e))
-            net = '0-0'
-    return net
+            ipip = ['0','0']
+    return ipip
 
 
 def net2ip(net_str, strict=False):
@@ -35,11 +49,11 @@ def net2ip(net_str, strict=False):
     :param strict: 是否校验网络地址 eg: False
     :return 返回list eg [ip1,ip2,...]
     """
-    ip_ip = net2ipip(net_str, strict=strict)
-    if ip_ip == '0-0':
+    ipip = net2ipip(net_str, strict=strict)
+    if ipip == ['0','0']:
         return []
     else:
-        return gen_ip(ip_ip)
+        return gen_ip(*ipip)
 
 
 def net2cidr(net_str, strict=False):
@@ -48,11 +62,10 @@ def net2cidr(net_str, strict=False):
     :param net_str: 传入合法网段,eg:  192.168.1.0/24 or 192.168.1.1-33 or 192.168.1.5-192.168.1.8
     :return 返回 ["192.168.1.0/24"]
     """
-    ip_ip = net2ipip(net_str, strict=strict)
-    start_ip, end_ip = ip_ip.split('-')
+    ipip = net2ipip(net_str, strict=strict)
     try:
         return [ipaddr.compressed for ipaddr in ipaddress.summarize_address_range(
-            ipaddress.IPv4Address(start_ip), ipaddress.IPv4Address(end_ip))]
+            ipaddress.IPv4Address(ipip[0]), ipaddress.IPv4Address(ipip[1]))]
     except:
         return []
 
@@ -65,7 +78,7 @@ def ip2ipip(iplist):
     """
     num_iplist = [ip2num(_) for _ in iplist]
     numnumlist = num2numnum(num_iplist)
-    return ["{}-{}".format(num2ip(a),num2ip(b)) for a, b in numnumlist]
+    return [[num2ip(a),num2ip(b)] for a, b in numnumlist]
 
 
 def ip2cidr(iplist):
